import { Stack, Typography, Button } from "@mui/material";
import { Dialog } from "@ess-ics/ce-ui-common";
import { ApiAlertError } from "../../common/Alerts/ApiAlertError";

export function IOCUndeployDialog({
  open,
  setOpen,
  submitCallback,
  ioc,
  error,
  resetError,
  buttonDisabled
}) {
  const handleClose = () => {
    setOpen(false);
    resetError();
  };

  const onSubmit = (event) => {
    event.preventDefault();

    submitCallback({
      iocId: ioc.id,
      createJobRequest: {
        type: "UNDEPLOY"
      }
    });
  };

  return (
    <Dialog
      open={open}
      onClose={handleClose}
      title={
        <Typography
          variant="h2"
          marginY={1}
        >
          Undeploy
        </Typography>
      }
      content={
        <Stack
          component="form"
          onSubmit={onSubmit}
          gap={1}
        >
          <Typography
            fontSize="small"
            fontStyle="italic"
            sx={{ marginBottom: "0.5rem" }}
          >
            Autosave files will not be affected and might need manual handling.
          </Typography>
          <Typography>
            Do you really want to undeploy {ioc.namingName} from{" "}
            {ioc?.activeDeployment?.host?.fqdn}?
          </Typography>
          {error && <ApiAlertError error={error} />}
          <Stack
            flexDirection="row"
            justifyContent="flex-end"
            gap={2}
            marginTop={1}
          >
            <Button
              onClick={handleClose}
              color="primary"
            >
              Cancel
            </Button>
            <Button
              color="primary"
              variant="contained"
              type="submit"
              disabled={!ioc || error || buttonDisabled}
            >
              Undeploy
            </Button>
          </Stack>
        </Stack>
      }
    />
  );
}
